==> vscat-1.0.0.tgz: package/tests/highlighting/diagnostics/html/tag-error/results/output.solarized-light.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`diagnostics suite html language tag-error test solarized-light theme 1`] = `
Object {
  "lines": Array [
    "[48;2;253;246;227m [38;2;35;120;147m 1 │ [39m[38;2;147;161;161m<[39m[38;2;38;139;210mhtml[39m[38;2;147;161;161m>[39m                                                                    [49m",
    "[48;2;253;246;227m [38;2;35;120;147m 2 │ [39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;147;161;161m<[39m[38;2;38;139;210mhead[39m[38;2;147;161;161m>[39m                                                                  [49m",
    "[48;2;253;246;227m [38;2;35;120;147m 3 │ [39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;147;161;161m<[39m[38;2;38;139;210mmeta[39m[38;2;172;183;186m·[39m[38;2;147;161;161mfoo[39m[38;2;101;123;131m=[39m[38;2;42;161;152m\\"bar\\"[39m[38;2;172;183;186m·[39m[38;2;147;161;161m/>[39m                                                    [49m",
    "[48;2;253;246;227m   [38;2;35;120;147m │ [39m[38;2;172;183;186m [39m[38;2;172;183;186m [39m[38;2;172;183;186m [39m[38;2;172;183;186m [39m[38;2;172;183;186m [39m[38;2;172;183;186m [39m[38;2;172;183;186m [39m[38;2;172;183;186m [39m[38;2;172;183;186m [39m[38;2;172;183;186m [39m[38;2;229;20;0m~~~[39m                                                             [49m",
    "[48;2;253;246;227m [38;2;35;120;147m 4 │ [39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;147;161;161m<[39m[38;2;38;139;210mmeta[39m[38;2;172;183;186m·[39m[38;2;147;161;161mcharset[39m[38;2;101;123;131m=[39m[38;2;42;161;152m\\"utf-8\\"[39m[38;2;172;183;186m·[39m[38;2;147;161;161m/>[39m                                              [49m",
    "[48;2;253;246;227m [38;2;35;120;147m 5 │ [39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;147;161;161m<[39m[38;2;38;139;210mtitle[39m[38;2;147;161;161m>[39m[38;2;101;123;131mmy[39m[38;2;172;183;186m·[39m[38;2;101;123;131mpage[39m[38;2;147;161;161m</[39m[38;2;38;139;210mtitle[39m[38;2;147;161;161m>[39m                                                [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ #93A1A1 │ <
 0 │  1, 5 │ #268BD2 │ html
 0 │  5, 6 │ #93A1A1 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  0, 2 │ #657B83 │   
 1 │  2, 3 │ #93A1A1 │ <
 1 │  3, 7 │ #268BD2 │ head
 1 │  7, 8 │ #93A1A1 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  0, 4 │ #657B83 │     
 2 │  4, 5 │ #93A1A1 │ <
 2 │  5, 9 │ #268BD2 │ meta
 2 │  9,10 │ #657B83 │  
 2 │ 10,13 │ #93A1A1 │ foo
 2 │ 13,14 │ #657B83 │ =
 2 │ 14,19 │ #2AA198 │ \\"bar\\"
 2 │ 19,20 │ #657B83 │  
 2 │ 20,22 │ #93A1A1 │ />
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  0, 4 │ #657B83 │     
 3 │  4, 5 │ #93A1A1 │ <
 3 │  5, 9 │ #268BD2 │ meta
 3 │  9,10 │ #657B83 │  
 3 │ 10,17 │ #93A1A1 │ charset
 3 │ 17,18 │ #657B83 │ =
 3 │ 18,25 │ #2AA198 │ \\"utf-8\\"
 3 │ 25,26 │ #657B83 │  
 3 │ 26,28 │ #93A1A1 │ />
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  0, 4 │ #657B83 │     
 4 │  4, 5 │ #93A1A1 │ <
 4 │  5,10 │ #268BD2 │ title
 4 │ 10,11 │ #93A1A1 │ >
 4 │ 11,18 │ #657B83 │ my page
 4 │ 18,20 │ #93A1A1 │ </
 4 │ 20,25 │ #268BD2 │ title
 4 │ 25,26 │ #93A1A1 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  0, 2 │ #657B83 │   
 5 │  2, 4 │ #93A1A1 │ </
 5 │  4, 8 │ #268BD2 │ head
 5 │  8, 9 │ #93A1A1 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  0, 2 │ #657B83 │   
 6 │  2, 3 │ #93A1A1 │ <
 6 │  3, 7 │ #268BD2 │ body
 6 │  7, 8 │ #93A1A1 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  0,11 │ #657B83 │     Content
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  0, 2 │ #657B83 │   
 8 │  2, 4 │ #93A1A1 │ </
 8 │  4, 8 │ #268BD2 │ body
 8 │  8, 9 │ #93A1A1 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  0, 2 │ #93A1A1 │ </
 9 │  2, 6 │ #268BD2 │ html
 9 │  6, 7 │ #93A1A1 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │ none  │         │
",
  ],
}
`;

==> vscat-1.0.1.tgz: package/tests/highlighting/diagnostics/html/tag-error/results/output.solarized-light.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`diagnostics suite html language tag-error test solarized-light theme 1`] = `
Object {
  "lines": Array [
    "[48;2;253;246;227m [38;2;35;120;147m 1 │ [39m[38;2;147;161;161m<[39m[38;2;38;139;210mhtml[39m[38;2;147;161;161m>[39m                                                                    [49m",
    "[48;2;253;246;227m [38;2;35;120;147m 2 │ [39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;147;161;161m<[39m[38;2;38;139;210mhead[39m[38;2;147;161;161m>[39m                                                                  [49m",
    "[48;2;253;246;227m [38;2;35;120;147m 3 │ [39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;147;161;161m<[39m[38;2;38;139;210mmeta[39m[38;2;172;183;186m·[39m[38;2;147;161;161mfoo[39m[38;2;101;123;131m=[39m[38;2;42;161;152m\\"bar\\"[39m[38;2;172;183;186m·[39m[38;2;147;161;161m/>[39m                                                    [49m",
    "[48;2;253;246;227m   [38;2;35;120;147m │ [39m[38;2;51;51;51m          [39m[38;2;229;20;0m~~~[39m                                                             [49m",
    "[48;2;253;246;227m [38;2;35;120;147m 4 │ [39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;147;161;161m<[39m[38;2;38;139;210mmeta[39m[38;2;172;183;186m·[39m[38;2;147;161;161mcharset[39m[38;2;101;123;131m=[39m[38;2;42;161;152m\\"utf-8\\"[39m[38;2;172;183;186m·[39m[38;2;147;161;161m/>[39m                                              [49m",
    "[48;2;253;246;227m [38;2;35;120;147m 5 │ [39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;172;183;186m·[39m[38;2;147;161;161m<[39m[38;2;38;139;210mtitle[39m[38;2;147;161;161m>[39m[38;2;101;123;131mmy[39m[38;2;172;183;186m·[39m[38;2;101;123;131mpage[39m[38;2;147;161;161m</[39m[38;2;38;139;210mtitle[39m[38;2;147;161;161m>[39m                                                [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ #93A1A1 │ <
 0 │  1, 5 │ #268BD2 │ html
 0 │  5, 6 │ #93A1A1 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  0, 2 │ #657B83 │   
 1 │  2, 3 │ #93A1A1 │ <
 1 │  3, 7 │ #268BD2 │ head
 1 │  7, 8 │ #93A1A1 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  0, 4 │ #657B83 │     
 2 │  4, 5 │ #93A1A1 │ <
 2 │  5, 9 │ #268BD2 │ meta
 2 │  9,10 │ #657B83 │  
 2 │ 10,13 │ #93A1A1 │ foo
 2 │ 13,14 │ #657B83 │ =
 2 │ 14,19 │ #2AA198 │ \\"bar\\"
 2 │ 19,20 │ #657B83 │  
 2 │ 20,22 │ #93A1A1 │ />
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  0, 4 │ #657B83 │     
 3 │  4, 5 │ #93A1A1 │ <
 3 │  5, 9 │ #268BD2 │ meta
 3 │  9,10 │ #657B83 │  
 3 │ 10,17 │ #93A1A1 │ charset
 3 │ 17,18 │ #657B83 │ =
 3 │ 18,25 │ #2AA198 │ \\"utf-8\\"
 3 │ 25,26 │ #657B83 │  
 3 │ 26,28 │ #93A1A1 │ />
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  0, 4 │ #657B83 │     
 4 │  4, 5 │ #93A1A1 │ <
 4 │  5,10 │ #268BD2 │ title
 4 │ 10,11 │ #93A1A1 │ >
 4 │ 11,18 │ #657B83 │ my page
 4 │ 18,20 │ #93A1A1 │ </
 4 │ 20,25 │ #268BD2 │ title
 4 │ 25,26 │ #93A1A1 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  0, 2 │ #657B83 │   
 5 │  2, 4 │ #93A1A1 │ </
 5 │  4, 8 │ #268BD2 │ head
 5 │  8, 9 │ #93A1A1 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  0, 2 │ #657B83 │   
 6 │  2, 3 │ #93A1A1 │ <
 6 │  3, 7 │ #268BD2 │ body
 6 │  7, 8 │ #93A1A1 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  0,11 │ #657B83 │     Content
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  0, 2 │ #657B83 │   
 8 │  2, 4 │ #93A1A1 │ </
 8 │  4, 8 │ #268BD2 │ body
 8 │  8, 9 │ #93A1A1 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  0, 2 │ #93A1A1 │ </
 9 │  2, 6 │ #268BD2 │ html
 9 │  6, 7 │ #93A1A1 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │ none  │         │
",
  ],
}
`;
